import { PolymorphicComponent } from '../utils';
import { PopupTypeMap } from './Popup.types';
/**
 *
 * Demos:
 *
 * - [Popup](https://mui.com/base-ui/react-popup/)
 *
 * API:
 *
 * - [Popup API](https://mui.com/base-ui/react-popup/components-api/#popup)
 */
declare const Popup: PolymorphicComponent<PopupTypeMap<{}, "div">>;
export { Popup };
